@@ -16,6 +16,8 @@ class SourceTypes(str, Enum):
     mobileapp_submit_facebook = 'mobileapp_submit_facebook'
     report_thread = 'report_thread'
     report_comment = 'report_comment'
+    mention_in_thread = 'mention_in_thread'
+    mention_in_comment = 'mention_in_comment'
 
 
 @dataclass
